==> pano_rtc-0.9.3.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/PanoWhiteboardNativeViewFactory.kt <==
package video.pano.pano_rtc

import android.content.Context
import android.view.View
import com.pano.rtc.api.RtcWbView
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.StandardMessageCodec
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory
import video.pano.pano_rtc.api.IRtcWbView

class PanoWhiteboardNativeViewFactory : PlatformViewFactory(StandardMessageCodec.INSTANCE) {

    override fun create(context: Context, viewId: Int, args: Any?): PlatformView {
        return PanoWhiteboardNativeView(context, viewId)
    }
}

class PanoWhiteboardNativeView(context: Context, viewId: Int) : FlutterWrapper(), PlatformView,
        IRtcWbView, MethodChannel.MethodCallHandler {
    private val view = RtcWbView(context)

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/whiteboard_surface_view_$viewId")
        methodChannel.setMethodCallHandler(this)
    }

    override fun getView(): View {
        return view
    }

    override fun dispose() {
        methodChannel.setMethodCallHandler(null)
    }

    override fun open(callback: Callback) {
        PanoRtcPlugin.engineManager.getRtcWhiteboardEngine()?.open(mapOf("view" to view), callback)
    }

    override fun startAnnotation(params: Map<String, *>, callback: Callback) {
        val channelId = params["channelId"] as String
        val annotation = PanoRtcPlugin.engineManager.annotationMgr?.getAnnotationById(channelId)
        annotation?.startAnnotation( mapOf("view" to view), callback)
    }

}

==> pano_rtc-0.9.4-dev.1.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/PanoWhiteboardNativeViewFactory.kt <==
package video.pano.pano_rtc

import android.content.Context
import android.view.View
import com.pano.rtc.api.RtcWbView
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.StandardMessageCodec
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory
import video.pano.pano_rtc.api.IRtcWbView

class PanoWhiteboardNativeViewFactory : PlatformViewFactory(StandardMessageCodec.INSTANCE) {

    override fun create(context: Context, viewId: Int, args: Any?): PlatformView {
        return PanoWhiteboardNativeView(viewId)
    }
}

class PanoWhiteboardNativeView(viewId: Int) : FlutterWrapper(), PlatformView,
        IRtcWbView, MethodChannel.MethodCallHandler {
    private val view = RtcWbView(PanoRtcPlugin.activity)

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/whiteboard_surface_view_$viewId")
        methodChannel.setMethodCallHandler(this)
    }

    override fun getView(): View {
        return view
    }

    override fun dispose() {
        methodChannel.setMethodCallHandler(null)
    }

    override fun open(callback: Callback) {
        PanoRtcPlugin.engineManager.getRtcWhiteboardEngine()?.open(mapOf("view" to view), callback)
    }

    override fun startAnnotation(params: Map<String, *>, callback: Callback) {
        val channelId = params["channelId"] as String
        val annotation = PanoRtcPlugin.engineManager.annotationMgr?.getAnnotationById(channelId)
        annotation?.startAnnotation( mapOf("view" to view), callback)
    }

}
